@@ -1,6 +1,7 @@
+mod client;
 mod discount_card;
 mod frequency;
-mod hafas_client;
+mod intermediate_location;
 mod journey;
 mod journeys_result;
 mod late_factor;
@@ -11,12 +12,12 @@ mod price;
 mod provider;
 mod remark;
 mod request_limiter;
-mod stop;
-mod stopover;
+mod station;
 
+pub use client::Client;
 pub use discount_card::DiscountCard;
 pub use frequency::Frequency;
-pub use hafas_client::HafasClient;
+pub use intermediate_location::IntermediateLocation;
 pub use journey::Journey;
 pub use journeys_result::JourneysResult;
 pub use journeys_result::TimeType;
@@ -28,5 +29,3 @@ pub use price::Price;
 pub use provider::Provider;
 pub use remark::Remark;
 pub use request_limiter::RequestLimiter;
-pub use stop::Stop;
-pub use stopover::Stopover;
